@@ -146,15 +146,16 @@ def ProcessAlarm():
 
                     if(records.Use_WakeUp_Song==True): #Delay alarm, so we can first play wake up song
                         print "* Alarm would be now:", records.AlarmTime_tuple
-                        print "* But wake Up song is enabled, delay alarm for max", records.WakeUp_Song_Duration/60, "minutes"
-                        records.AlarmTime_seconds=min(records.AlarmTime_seconds+records.WakeUp_Song_Duration, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
+                        print "* But wake Up song is enabled, delay alarm for", records.WakeUp_Song_Duration/60, "minutes"
+                        records.AlarmTime_seconds=min(records.AlarmTime_seconds+records.WakeUp_Song_Duration+10, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
                         records.AlarmTime_tuple=Seconds2Tuple(records.AlarmTime_seconds)
                         data.WakeUp_SongIsActive=True
                         records.WakeUp_Song_Start_tuple=Seconds2Tuple(now)
                         print "* Delay alarm until:", records.AlarmTime_tuple
 
                         print "** Play wake up song"
-                        PlaySong(records.WakeUp_Song_Volume, records.WakeUp_Song)
+#                        PlaySong(records.WakeUp_Song_Volume, records.WakeUp_Song)
+                        PlaySong(0, records.WakeUp_Song) #startquiet, get louder over time
 
                     print "*", strftime("%x %X"), "ProcessAlarm => SetAlarm" #for log file
                     SetAlarm() #set alarm to go off now (or with wake up song delay)
@@ -176,6 +177,10 @@ def ProcessAlarm():
             CloseMediaPlayer() #close media player
 
 
+    if(data.WakeUp_SongIsActive==True): #when WakeUp music is active, increase volume over time
+        if(records.WakeUp_Song_Volume>data.CurrentVolume):
+            SetVolume(data.CurrentVolume+1)
+            print "Increase volume to:", data.CurrentVolume
 
 
 ###########################################################################
